/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_lv extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AUD", "AU$" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "JPY", "\u00a5" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LVL", "Ls" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Apvienoto Ar\u0101bu Emir\u0101tu dirh\u0113ms" },
            { "afn", "Afganist\u0101nas afg\u0101ns" },
            { "all", "Alb\u0101nijas leks" },
            { "amd", "Arm\u0113nijas drams" },
            { "ang", "N\u012bderlandes Anti\u013cu guldenis" },
            { "aoa", "Angolas kvanza" },
            { "ars", "Argent\u012bnas peso" },
            { "ats", "Austrijas \u0161ili\u0146\u0161" },
            { "aud", "Austr\u0101lijas dol\u0101rs" },
            { "awg", "Arubas guldenis" },
            { "azm", "Azerbaid\u017e\u0101nas manats (1993\u20132006)" },
            { "azn", "Azerbaid\u017e\u0101nas manats" },
            { "bam", "Bosnijas un Hercogovinas konvert\u0113jam\u0101 marka" },
            { "bbd", "Barbadosas dol\u0101rs" },
            { "bdt", "Banglade\u0161as taka" },
            { "bef", "Be\u013c\u0123ijas franks" },
            { "bgn", "Bulg\u0101rijas leva" },
            { "bhd", "Bahreinas din\u0101rs" },
            { "bif", "Burundi franks" },
            { "bmd", "Bermudu dol\u0101rs" },
            { "bnd", "Brunejas dol\u0101rs" },
            { "bob", "Bol\u012bvijas boliviano" },
            { "brl", "Braz\u012blijas re\u0101ls" },
            { "bsd", "Bahamu dol\u0101rs" },
            { "btn", "But\u0101nas ngultrums" },
            { "bwp", "Botsvanas pula" },
            { "byn", "Baltkrievijas rubelis" },
            { "byr", "Baltkrievijas rubelis (2000\u20132016)" },
            { "bzd", "Belizas dol\u0101rs" },
            { "cad", "Kan\u0101das dol\u0101rs" },
            { "cdf", "KDR franks" },
            { "chf", "\u0160veices franks" },
            { "clp", "\u010c\u012bles peso" },
            { "cnh", "\u0136\u012bnas jua\u0146a (of\u0161ors)" },
            { "cny", "\u0136\u012bnas jua\u0146s" },
            { "cop", "Kolumbijas peso" },
            { "cou", "Kolumbijas re\u0101ls" },
            { "crc", "Kostarikas kolons" },
            { "cuc", "Kubas konvert\u0113jamais peso" },
            { "cup", "Kubas peso" },
            { "cve", "Kaboverdes eskudo" },
            { "cyp", "Kipras m\u0101rci\u0146a" },
            { "czk", "\u010cehijas krona" },
            { "dem", "V\u0101cijas marka" },
            { "djf", "D\u017eibutijas franks" },
            { "dkk", "D\u0101nijas krona" },
            { "dop", "Dominik\u0101nas peso" },
            { "dzd", "Al\u017e\u012brijas din\u0101rs" },
            { "eek", "Igaunijas krona" },
            { "egp", "\u0112\u0123iptes m\u0101rci\u0146a" },
            { "ern", "Eritrejas nakfa" },
            { "esp", "Sp\u0101nijas peseta" },
            { "etb", "Etiopijas birs" },
            { "eur", "eiro" },
            { "fim", "Somijas marka" },
            { "fjd", "Fid\u017ei dol\u0101rs" },
            { "fkp", "Folklenda Salu m\u0101rci\u0146a" },
            { "frf", "Francijas franks" },
            { "gbp", "Lielbrit\u0101nijas m\u0101rci\u0146a" },
            { "gel", "Gruzijas lari" },
            { "ghs", "Ganas sedi" },
            { "gip", "Gibralt\u0101ra m\u0101rci\u0146a" },
            { "gmd", "Gambijas dalasi" },
            { "gnf", "Gvinejas franks" },
            { "grd", "Grie\u0137ijas drahma" },
            { "gtq", "Gvatemalas ketsals" },
            { "gyd", "Gaj\u0101nas dol\u0101rs" },
            { "hkd", "Honkongas dol\u0101rs" },
            { "hnl", "Hondurasas lemp\u012bra" },
            { "hrk", "Horv\u0101tijas kuna" },
            { "htg", "Haiti gurds" },
            { "huf", "Ung\u0101rijas forints" },
            { "idr", "Indon\u0113zijas r\u016bpija" },
            { "iep", "\u012arijas m\u0101rci\u0146a" },
            { "ils", "Izra\u0113las \u0161ekelis" },
            { "inr", "Indijas r\u016bpija" },
            { "iqd", "Ir\u0101kas din\u0101rs" },
            { "irr", "Ir\u0101nas ri\u0101ls" },
            { "isk", "Islandes krona" },
            { "itl", "It\u0101lijas lira" },
            { "jmd", "Jamaikas dol\u0101rs" },
            { "jod", "Jord\u0101nas din\u0101rs" },
            { "jpy", "Jap\u0101nas jena" },
            { "kes", "Kenijas \u0161ili\u0146\u0161" },
            { "kgs", "Kirgizst\u0101nas soms" },
            { "khr", "Kambod\u017eas riels" },
            { "kmf", "Komoru franks" },
            { "kpw", "Zieme\u013ckorejas vona" },
            { "krw", "Dienvidkorejas vona" },
            { "kwd", "Kuveitas din\u0101rs" },
            { "kyd", "Kaimanu salu dol\u0101rs" },
            { "kzt", "Kazahst\u0101nas tenge" },
            { "lak", "Laosas kips" },
            { "lbp", "Lib\u0101nas m\u0101rci\u0146a" },
            { "lkr", "\u0160rilankas r\u016bpija" },
            { "lrd", "Lib\u0113rijas dol\u0101rs" },
            { "lsl", "Lesoto loti" },
            { "ltl", "Lietuvas lits" },
            { "luf", "Luksemburgas franks" },
            { "lvl", "Latvijas lats" },
            { "lvr", "Latvijas rublis" },
            { "lyd", "L\u012bbijas din\u0101rs" },
            { "mad", "Marokas dirh\u0113ms" },
            { "mdl", "Moldovas leja" },
            { "mga", "Madagaskaras ariari" },
            { "mkd", "Ma\u0137edonijas den\u0101rs" },
            { "mlf", "CFA (\u0100frikas) franks" },
            { "mmk", "Mjanmas kjats" },
            { "mnt", "Mongolijas tugriks" },
            { "mop", "Makao pataka" },
            { "mro", "Maurit\u0101nijas ugija (1973\u20132017)" },
            { "mru", "Maurit\u0101nijas ugija" },
            { "mtl", "Maltas lira" },
            { "mtp", "Maltas m\u0101rci\u0146a" },
            { "mur", "Maur\u012bcijas r\u016bpija" },
            { "mvr", "Mald\u012bvijas r\u016bfija" },
            { "mwk", "Mal\u0101vijas kva\u010da" },
            { "mxn", "Meksikas peso" },
            { "myr", "Malaizijas ringits" },
            { "mze", "Mozambikas eskudo" },
            { "mzm", "Mozambikas vecais metikals" },
            { "mzn", "Mozambikas metikals" },
            { "nad", "Nam\u012bbijas dol\u0101rs" },
            { "ngn", "Nig\u0113rijas naira" },
            { "nio", "Nikaragvas kordoba" },
            { "nlg", "N\u012bderlandes guldenis" },
            { "nok", "Norv\u0113\u0123ijas krona" },
            { "npr", "Nep\u0101las r\u016bpija" },
            { "nzd", "Jaunz\u0113landes dol\u0101rs" },
            { "omr", "Om\u0101nas ri\u0101ls" },
            { "pab", "Panamas balboa" },
            { "pen", "Peru sols" },
            { "pgk", "Papua-Jaungvinejas kina" },
            { "php", "Filip\u012bnu peso" },
            { "pkr", "Pakist\u0101nas r\u016bpija" },
            { "pln", "Polijas zlots" },
            { "pte", "Portug\u0101les eskudo" },
            { "pyg", "Paragvajas guarani" },
            { "qar", "Kataras ri\u0101ls" },
            { "rol", "Rum\u0101nijas vec\u0101 leja" },
            { "ron", "Rum\u0101nijas leja" },
            { "rsd", "Serbijas din\u0101rs" },
            { "rub", "Krievijas rublis" },
            { "rwf", "Ruandas franks" },
            { "sar", "Sa\u016bda Ar\u0101bijas ri\u0101ls" },
            { "sbd", "Z\u0101lamana Salu dol\u0101rs" },
            { "scr", "Sei\u0161elu salu r\u016bpija" },
            { "sdg", "Sud\u0101nas m\u0101rci\u0146a" },
            { "sek", "Zviedrijas krona" },
            { "sgd", "Singap\u016bras dol\u0101rs" },
            { "shp", "Sv.Hel\u0113nas salas m\u0101rci\u0146a" },
            { "sit", "Slov\u0113nijas tolars" },
            { "skk", "Slovakijas krona" },
            { "sll", "Sjerraleones leone" },
            { "sos", "Som\u0101lijas \u0161ili\u0146\u0161" },
            { "srd", "Surinamas dol\u0101rs" },
            { "srg", "Surinamas guldenis" },
            { "ssp", "Dienvidsud\u0101nas m\u0101rci\u0146a" },
            { "std", "Santome un Prinsipi dobra (1977\u20132017)" },
            { "stn", "Santome un Prinsipi dobra" },
            { "svc", "Salvadoras kolons" },
            { "syp", "S\u012brijas m\u0101rci\u0146a" },
            { "szl", "Svazilendas lilangeni" },
            { "thb", "Taizemes b\u0101ts" },
            { "tjs", "Tad\u017eikist\u0101nas somons" },
            { "tmm", "Turkmenist\u0101nas manats (1993\u20132009)" },
            { "tmt", "Turkmenist\u0101nas manats" },
            { "tnd", "Tunisijas din\u0101rs" },
            { "top", "Tongas paanga" },
            { "trl", "Turcijas lira (1922\u20132005)" },
            { "try", "Turcijas lira" },
            { "ttd", "Trinid\u0101das un Tob\u0101go dol\u0101rs" },
            { "twd", "Taiv\u0101nas jaunais dol\u0101rs" },
            { "tzs", "Tanz\u0101nijas \u0161ili\u0146\u0161" },
            { "uah", "Ukrainas grivna" },
            { "ugx", "Ugandas \u0161ili\u0146\u0161" },
            { "usd", "ASV dol\u0101rs" },
            { "uyu", "Urugvajas peso" },
            { "uzs", "Uzbekist\u0101nas sums" },
            { "veb", "Venecu\u0113las boliv\u0101rs (1871\u20132008)" },
            { "vef", "Venecu\u0113las boliv\u0101rs (2008\u20132018)" },
            { "ves", "Venecu\u0113las boliv\u0101rs" },
            { "vnd", "Vjetnamas dongi" },
            { "vuv", "Vanuatu vatu" },
            { "wst", "Samoa tala" },
            { "xaf", "Centr\u0101l\u0101frikas CFA franks" },
            { "xag", "sudrabs" },
            { "xau", "zelts" },
            { "xba", "Eiropas nor\u0113\u0137inu vien\u012bba EURCO" },
            { "xbb", "Eiropas naudas vien\u012bba" },
            { "xbc", "Eiropas nor\u0113\u0137inu vien\u012bba (XBC)" },
            { "xbd", "Eiropas nor\u0113\u0137inu vien\u012bba (XBD)" },
            { "xcd", "Austrumkar\u012bbu dol\u0101rs" },
            { "xdr", "Speci\u0101l\u0101s aiz\u0146\u0113muma ties\u012bbas" },
            { "xeu", "Eiropas nor\u0113\u0137inu vien\u012bba" },
            { "xfo", "Francijas zelta franks" },
            { "xfu", "Francijas UIC franks" },
            { "xof", "Rietum\u0101frikas CFA franks" },
            { "xpd", "pall\u0101dijs" },
            { "xpf", "CFP franks" },
            { "xpt", "plat\u012bns" },
            { "xts", "Testa val\u016btas kods" },
            { "xxx", "Nezin\u0101ma val\u016bta" },
            { "yer", "Jemenas ri\u0101ls" },
            { "zar", "Dienvid\u0101frikas rends" },
            { "zmk", "Zambijas kva\u010da (1968\u20132012)" },
            { "zmw", "Zambijas kva\u010da" },
            { "zwd", "Zimbabves dol\u0101rs" },
            { "zwl", "Zimbabves dol\u0101rs (2009)" },
        };
        return data;
    }
}
